pub struct SpDescriptor { /* private fields */ }Expand description
A BIP 392 Silent Payments descriptor.
Contains an SpAddress (scan + spend public keys) plus optional BIP 393
annotations for wallet configuration.
Construction
use silent_payments_core::address::SpAddress;
use silent_payments_core::keys::{ScanPublicKey, SpendPublicKey};
use bitcoin::Network;
use bitcoin::secp256k1::{Secp256k1, SecretKey};
use silent_payments_descriptor::SpDescriptor;
let secp = Secp256k1::new();
let sk = SecretKey::from_slice(&[0x01; 32]).unwrap();
let pk = sk.public_key(&secp);
let addr = SpAddress::new(ScanPublicKey::from(pk), SpendPublicKey::from(pk), Network::Bitcoin);
let desc = SpDescriptor::from(addr).with_birthday_height(850000);
assert_eq!(desc.birthday_height(), Some(850000));Implementations
Sourceimpl SpDescriptor
impl SpDescriptor
Sourcepub fn birthday_height(&self) -> Option<u32>
pub fn birthday_height(&self) -> Option<u32>
Returns the wallet birthday height annotation, if set.
Sourcepub fn max_labels(&self) -> Option<u32>
pub fn max_labels(&self) -> Option<u32>
Returns the max labels annotation, if set.
Sourcepub fn with_birthday_height(self, height: u32) -> SpDescriptor
pub fn with_birthday_height(self, height: u32) -> SpDescriptor
Returns a new descriptor with the birthday height annotation set.
Does not mutate self; returns a new value (immutable builder pattern).
Sourcepub fn with_gap_limit(self, limit: u32) -> SpDescriptor
pub fn with_gap_limit(self, limit: u32) -> SpDescriptor
Returns a new descriptor with the gap limit annotation set.
Does not mutate self; returns a new value (immutable builder pattern).
Sourcepub fn with_max_labels(self, max: u32) -> SpDescriptor
pub fn with_max_labels(self, max: u32) -> SpDescriptor
Returns a new descriptor with the max labels annotation set.
Does not mutate self; returns a new value (immutable builder pattern).